@@ -8,7 +8,7 @@ use Statistics::Lite qw(max mean median stddev);
 use String::Util qw(hascontent nocontent);
 use Config;
 
-$Lingua::Norms::SUBTLEX::VERSION = '0.02';
+$Lingua::Norms::SUBTLEX::VERSION = '0.03';
 
 =head1 NAME
 
@@ -16,7 +16,7 @@ Lingua::Norms::SUBTLEX - Retrieve frequency values and frequency-based lists fro
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -201,7 +201,7 @@ sub cd_pct {
 
 =head3 cd_log
 
-Returns log10(L<cd_pct|cd_pct> + 1) for the given string, with 4-digit precision. This corresponds to the measure "Lg10CD" described in Brysbaert and New (2009), where it is stated that "this is the best value to use if one wants to match words on word frequency" (p. 988). Note: "cd" stands for "contextual diversity," which is based on the number of films and TV episodes in which the string was represented.
+Returns log10(L<cd_pct|Lingua::Norms::SUBTLEX/cd_pct> + 1) for the given string, with 4-digit precision. This corresponds to the measure "Lg10CD" described in Brysbaert and New (2009), where it is stated that "this is the best value to use if one wants to match words on word frequency" (p. 988). Note: "cd" stands for "contextual diversity," which is based on the number of films and TV episodes in which the string was represented.
 
 =cut
 
@@ -298,7 +298,7 @@ sub pos {
 
 =head2 Descriptive frequency statistics for lists
 
-These methods return a descriptive statistic (mean, median or standard deviation) for a list of B<strings>. Like L<freq_hash|Lingua::Norms::SUBTLEX/freq_hash>, they take an optional argument B<scale> to specify if the returned values should be raw frequencies per million, log frequencies, or zip-frequencies.
+These methods return a descriptive statistic (mean, median or standard deviation) for a list of B<strings>. Like L<freqhash|Lingua::Norms::SUBTLEX/freqhash>, they take an optional argument B<scale> to specify if the returned values should be raw frequencies per million, log frequencies, or zip-frequencies.
 
 =head3 mean_freq
 
@@ -661,7 +661,7 @@ sub _get_orthon_ldist {
         next if $. == 1;    # skip column heading line
         /^([^,]+)/sxm or next;
         my $test = lc($1);
-        push @tests, $test;
+        next if $word eq $test;
         push @ldists, $ortho->ldist( $word, $test );
     }
     close $fh;
@@ -764,8 +764,8 @@ Roderick Garton, C<< <rgarton at cpan.org> >>
 
 =head1 BUGS AND LIMITATIONS
 
-Please report any bugs or feature requests to C<bug-lingua-norms-subtlfreq-0.02 at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Lingua-Norms-SUBTLEX-0.02>.  I will be notified, and then you'll
+Please report any bugs or feature requests to C<bug-lingua-norms-subtlfreq-0.03 at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Lingua-Norms-SUBTLEX-0.03>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
 =head1 TO DO
@@ -795,19 +795,19 @@ You can also look for information at:
 
 =item * RT: CPAN's request tracker (report bugs here)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Lingua-Norms-SUBTLEX-0.02>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Lingua-Norms-SUBTLEX-0.03>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
-L<http://annocpan.org/dist/Lingua-Norms-SUBTLEX-0.02>
+L<http://annocpan.org/dist/Lingua-Norms-SUBTLEX-0.03>
 
 =item * CPAN Ratings
 
-L<http://cpanratings.perl.org/d/Lingua-Norms-SUBTLEX-0.02>
+L<http://cpanratings.perl.org/d/Lingua-Norms-SUBTLEX-0.03>
 
 =item * Search CPAN
 
-L<http://search.cpan.org/dist/Lingua-Norms-SUBTLEX-0.02/>
+L<http://search.cpan.org/dist/Lingua-Norms-SUBTLEX-0.03/>
 
 =back
 
